@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: additem.pl,v 1.27.2.22 2006/09/12 09:11:45 hdl Exp $
+# $Id: additem.pl,v 1.27.2.22.2.1 2007/02/27 20:51:34 tipaul Exp $
 
 # Copyright 2000-2002 Katipo Communications
 #
@@ -284,13 +284,14 @@ foreach my $tag (sort keys %{$tagslib}) {
 # 		print $input->redirect(".pl?bibid=$bibid") if ($test);
 		# search for itemcallnumber if applicable
 ##Lc callnumbers expect 2 subfields like 050ab or 090ab . Modified to accept 2 subfields
-		if ($tagslib->{$tag}->{$subfield}->{kohafield} eq 'items.itemcallnumber' && C4::Context->preference('itemcallnumber')) {
+warn "$value / $tag / $subfield";
+		if (!$value && $tagslib->{$tag}->{$subfield}->{kohafield} eq 'items.itemcallnumber' && C4::Context->preference('itemcallnumber')) {
 			my $CNtag = substr(C4::Context->preference('itemcallnumber'),0,3);
 			my $CNsubfield = substr(C4::Context->preference('itemcallnumber'),3,1);
 			my $CNsubfield2 = substr(C4::Context->preference('itemcallnumber'),4,1);
-			my $temp = $record->field($CNtag);
-			if ($temp) {
-				$value = ($temp->subfield($CNsubfield)).' '.($temp->subfield($CNsubfield2));
+			my $temp2 = $temp->field($CNtag);
+			if ($temp2) {
+				$value = ($temp2->subfield($CNsubfield)).' '.($temp2->subfield($CNsubfield2));
 #remove any trailing space incase one subfield is used
 			$value=~s/^\s+|\s+$//g;
 			}
