@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: authorities.pl,v 1.8.2.11 2006/08/10 11:41:45 tipaul Exp $
+# $Id: authorities.pl,v 1.8.2.11.2.1 2007/02/12 10:05:13 toins Exp $
 
 # Copyright 2000-2002 Katipo Communications
 #
@@ -330,7 +330,7 @@ if ($op eq "add") {
 	my @ind_tag = $input->param('ind_tag');
 	my @indicator = $input->param('indicator');
 	my $record;
-	if (C4::Context->preference('TemplateEncoding') eq "iso-8859-1") {
+ 	if (C4::Context->preference('TemplateEncoding') eq "iso-8859-1"||C4::Context->preference('marcflavour') eq "UNIMARC") {
         my %indicators;
         for (my $i=0;$i<=$#ind_tag;$i++) {
             $indicators{$ind_tag[$i]} = $indicator[$i];
@@ -376,7 +376,7 @@ if ($op eq "add") {
 	my @ind_tag = $input->param('ind_tag');
 	my @indicator = $input->param('indicator');
 	my $record;
-	if (C4::Context->preference('TemplateEncoding') eq "iso-8859-1") {
+	if (C4::Context->preference('TemplateEncoding') eq "iso-8859-1" ||C4::Context->preference('marcflavour') eq "UNIMARC") {
         my %indicators;
         for (my $i=0;$i<=$#ind_tag;$i++) {
             $indicators{$ind_tag[$i]} = $indicator[$i];
