@@ -27,6 +27,7 @@ my $CGIsupplier=CGI::scrolling_list( -name     => 'supplierid',
 			-default  => $supplierid,
 			-labels   => \%supplierlist,
 			-size     => 1,
+ 			-tabindex=>'',
 			-multiple => 0 );
 
 my @lateissues;
@@ -49,6 +50,9 @@ $template->param(
 	lateissues => \@lateissues,
 	phone => $supplierinfo[0]->{phone},
 	booksellerfax => $supplierinfo[0]->{booksellerfax},
-	bookselleremail => $supplierinfo[0]->{bookselleremail},
+	contemail => $supplierinfo[0]->{contemail},
+	intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
+		intranetstylesheet => C4::Context->preference("intranetstylesheet"),
+		IntranetNav => C4::Context->preference("IntranetNav"),
 	);
 output_html_with_http_headers $query, $cookie, $template->output;
