@@ -142,8 +142,8 @@ sub newsubscription {
 
 	# calculate issue number
 	my $serialseq = Get_Seq($val);
-	$sth = $dbh->prepare("insert into serial (serialseq,subscriptionid,biblionumber,status, planneddate) values (?,?,?,?,?)");
-	$sth->execute($serialseq, $subscriptionid, $val->{'biblionumber'}, 1, format_date_in_iso($startdate));
+	$sth = $dbh->prepare("insert into serial (serialseq,subscriptionid,biblionumber,status, planneddate,publisheddate) values (?,?,?,?,?,?)");
+    $sth->execute($serialseq, $subscriptionid, $val->{'biblionumber'}, 1, format_date_in_iso($startdate), format_date_in_iso($startdate));
 	return $subscriptionid;
 }
 
@@ -469,7 +469,7 @@ sub serialchangestatus {
 }
 
 sub newissue {
-	my ($serialseq,$subscriptionid,$biblionumber,$status, $publisheddate, $planneddate) = @_;
+    my ($serialseq,$subscriptionid,$biblionumber,$status, $publisheddate, $planneddate) = @_;
 	my $dbh = C4::Context->dbh;
 	my $sth = $dbh->prepare("SELECT missinglist,recievedlist from subscriptionhistory where subscriptionid=?");
 	$sth->execute($subscriptionid);
@@ -611,7 +611,8 @@ sub delissue {
 
 sub Get_Next_Date(@) {
 	my ($planneddate,$subscription) = @_;
-	my $resultdate;
+    my $resultdate;
+#     $planneddate = format_date($planneddate);
 	if ($subscription->{periodicity} == 1) {
 		$resultdate=DateCalc($planneddate,"1 day");
 	}
@@ -644,8 +645,10 @@ sub Get_Next_Date(@) {
 	}
 	if ($subscription->{periodicity} == 11) {
 		$resultdate=DateCalc($planneddate,"2 years");
-	}
-    return format_date_in_iso($resultdate);
+    }
+    $resultdate =~ /(....)(..)(..)/;
+    $resultdate="$1-$2-$3";
+    return $resultdate;
 }
 
 sub Get_Seq {
@@ -709,12 +712,14 @@ sub hassubscriptionexpired {
 	} else {
 		#a little bit more tricky if based on X weeks/months : search if the latest issue waited is not after subscription startdate + duration
 		my $sth = $dbh->prepare("SELECT max(planneddate) from serial where subscriptionid=?");
-		$sth->execute($subscriptionid);
-		my $res = ParseDate(format_date_in_iso($sth->fetchrow));
+        $sth->execute($subscriptionid);
+        my ($planneddate) = $sth->fetchrow;
+		my $res = ParseDate($planneddate);
 		my $endofsubscriptiondate;
-		$endofsubscriptiondate = DateCalc(format_date_in_iso($subscription->{startdate}),$subscription->{monthlength}." months") if ($subscription->{monthlength});
-		$endofsubscriptiondate = DateCalc(format_date_in_iso($subscription->{startdate}),$subscription->{weeklength}." weeks") if ($subscription->{weeklength});
-		return 1 if ($res >= $endofsubscriptiondate);
+		$endofsubscriptiondate = DateCalc($subscription->{startdate},"+".$subscription->{monthlength}." months") if ($subscription->{monthlength});
+		$endofsubscriptiondate = DateCalc($subscription->{startdate},"+".$subscription->{weeklength}." weeks") if ($subscription->{weeklength});
+#         warn "res $res ($planneddate) : end : $endofsubscriptiondate ".$subscription->{startdate}." ".$subscription->{monthlength}." months";
+        return 1 if ($res >= $endofsubscriptiondate);
 		return 0;
 	}
 }
