@@ -3,7 +3,7 @@
 
 package C4::Circulation::Circ2;
 
-# $Id: Circ2.pm,v 1.87.2.16 2006/09/14 14:31:33 oleonard Exp $
+# $Id: Circ2.pm,v 1.87.2.16.2.2 2007/02/12 10:24:08 toins Exp $
 
 #package to deal with Returns
 #written 3/11/99 by olwen@katipo.co.nz
@@ -466,11 +466,14 @@ sub transferbook {
 		$dotransfer = 0;
 	}
 	# check if it is still issued to someone, return it...
-	my ($currentborrower) = currentborrower($iteminformation->{'itemnumber'});
-	if ($currentborrower) {
-		returnbook($barcode, $fbr);
-		$messages->{'WasReturned'} = $currentborrower;
-	}
+    # this sub to be used to transfer books between branches while the book is
+    # on loan.
+#	my ($currentborrower) = currentborrower($iteminformation->{'itemnumber'});
+#	if ($currentborrower) {
+#		returnbook($barcode, $fbr);
+#		$messages->{'WasReturned'} = $currentborrower;
+#	}
+
 	# find reserves.....
 	# FIXME - Don't call &CheckReserves unless $ignoreRs is true.
 	# That'll save a database query.
@@ -909,7 +912,7 @@ sub issuebook {
 		$sth->execute($borrower->{'borrowernumber'}, $iteminformation->{'itemnumber'}, $dateduef, $env->{'branchcode'});
 		$sth->finish;
 		$iteminformation->{'issues'}++;
-		$sth=$dbh->prepare("update items set issues=? where itemnumber=?");
+		$sth=$dbh->prepare("update items set issues=?,datelastborrowed = now() where itemnumber=?");
 		$sth->execute($iteminformation->{'issues'},$iteminformation->{'itemnumber'});
 		$sth->finish;
 		&itemseen($iteminformation->{'itemnumber'});
