@@ -668,7 +668,8 @@ sub fixEncoding {
     my $targetcharset="utf8" if (C4::Context->preference("TemplateEncoding") eq "utf-8");
     $targetcharset="latin1" if (C4::Context->preference("TemplateEncoding") eq "iso-8859-1");
     my $decoder = guess_encoding($marc, qw/utf8 latin1/);
-    die $decoder unless ref($decoder);
+#     die $decoder unless ref($decoder);
+    if (ref($decoder)) {
     my $newRecord=MARC::Record->new();
     foreach my $field ($record->fields()){
       if ($field->tag()<'010'){
@@ -698,6 +699,9 @@ sub fixEncoding {
   } else {
     return $record;
   }
+  } else {
+    return $record;
+  }
 }
 1;
 __END__
