@@ -381,9 +381,9 @@ if (C4::Context->preference("sortbynonfiling")) {
 	# HINT : biblionumber as bn is important. The hash is fills biblionumber with items.biblionumber.
 	# so if you dont' has an item, you get a not nice empty value.
 	$sth = $dbh->prepare("SELECT biblio.biblionumber as bn,biblioitems.*,biblio.*, marc_biblio.bibid,itemtypes.notforloan,itemtypes.description
-							FROM biblio, marc_biblio 
-							LEFT JOIN biblioitems on biblio.biblionumber = biblioitems.biblionumber
-							LEFT JOIN itemtypes on itemtypes.itemtype=biblioitems.itemtype
+							FROM  marc_biblio , biblio
+							LEFT JOIN biblioitems on ( biblio.biblionumber = biblioitems.biblionumber )
+							LEFT JOIN itemtypes on (itemtypes.itemtype=biblioitems.itemtype)
 							WHERE biblio.biblionumber = marc_biblio.biblionumber AND bibid = ?");
         my $sth_subtitle = $dbh->prepare("SELECT subtitle FROM bibliosubtitle WHERE biblionumber=?"); # Added BY JF for Subtitles
 	my @finalresult = ();
@@ -659,9 +659,9 @@ sub getMARCsubjects {
 		$maxtag = "699";
 	} else {           # assume unimarc if not marc21
 		$mintag = "600";
-		$maxtag = "699";
+		$maxtag = "611";
 	}
-	my $sth=$dbh->prepare("SELECT `subfieldvalue`,`subfieldcode`,`tagorder`,`tag` FROM `marc_subfield_table` WHERE `bibid`= ? AND `subfieldcode` NOT IN ('2','4','6','8') AND `tag` BETWEEN ? AND ? ORDER BY `tagorder`,`subfieldorder`");
+	my $sth=$dbh->prepare("SELECT `subfieldvalue`,`subfieldcode`,`tagorder`,`tag` FROM `marc_subfield_table` WHERE `bibid`= ? AND `subfieldcode` NOT IN ('2','3','4','6','8') AND `tag` BETWEEN ? AND ? ORDER BY `tagorder`,`subfieldorder`");
 	# Subfield exclusion for $2, $4, $6, $8 protects against searching for
 	# variant data in otherwise invariant authorised subject headings when all
 	# returned subfields are used to form a query for matching subjects.  One
